=====
GOUDA
=====


Good Old Utilities for Data Analysis


Description
===========

These are a bunch of miscellaneous data/image utilities that have been made as needed. Full documentation on its way.

Installation
============

For pip: pip install gouda

For conda: conda install gouda -c smullan
